# Copyright 2001, Jan D. Wolter, All Rights Reserved.  #


# @itemh= ft_browse($confh, \$isel, $qry)
#  Get handles for many items in the given conference.  The query string is
#  an HTTP format string setting the variables 'rsel', 'showforgotten' and
#  'reverse' and 'sincedate'.  The query string starts with an & if it is not
#  empty.  An array of item handles is returned.  Each item handle has fields
#  including:
#
#      confh       - conference handle
#      number	   - Item number
#      title	   - Item title
#      linkdate	   - Date entered or linked
#      lastdate    - Date of most recent response
#      maxresp     - Maximum response number
#      firstresp   - Number of first returned response
#      frozen      - True if frozen
#      retired     - True if retired
#      forgotten   - True if forgotten
#      authorid    - Login of author of resp 0
#      authoruid   - Uid number of author of resp 0
#      authorname  - Fullname of author of resp 0
 
sub ft_browse {
    my ($confh, $isel, $qry)= @_;
    my (@iha, $itemh, $i, $page);

    $page= ft_runscript($sysh, "/fronttalk/browse",
    	"conf=$confh->{alias}&isel=".ft_httpquote($isel).$qry, 1)
    	or return @iha;

    print "BROWSE:\n$page\n" if $debug;

    $itemh->{confh}= $confh;

    # Parse info out of conference info page
    $i= 0;
    while ($tok= ft_parse(\$page))
    {
	if ($tok->{TOKEN} eq 'ITEM')
	{
	    # create the new itemhandle
	    $iha[$i]->{confh}= $confh;
	    $itemh= $iha[$i];
	    $i++;

	    $itemh->{number}= $tok->{N};
	    $itemh->{title}= ft_unquote($tok->{TITLE});
	    $itemh->{linkdate}= $tok->{LINKDATE};
	    $itemh->{lastdate}= $tok->{LASTDATE};
	    $itemh->{readdate}= $tok->{READDATE};
	    $itemh->{maxresp}= $tok->{MAXRESP};
	    $itemh->{firstresp}= $tok->{MAXRESP} - $tok->{NEWRESP};
	    $itemh->{frozen}= $tok->{FROZEN};
	    $itemh->{forgotten}= $tok->{FORGOTTEN};
	    $itemh->{retired}= $tok->{RETIRED};
	    $itemh->{linked}= $tok->{LINKED};
	    ($itemh->{authorid}, $itemh->{authoruid}, $itemh->{authorname})=
	    	split /,/, ft_unquote($tok->{AUTHOR}), 3;
	}
	elsif ($tok->{TOKEN} eq 'ERROR')
	{
	    ($ft_err,$ft_errmsg)= ('BTE1',"Request failed: $tok->{MSG}");
	    return @iha;
	}
    }

    return @iha;
}


# ft_conflist()
#  Get an array of handles for the lines of the conference menu.
#  Each array element has the following hash fields:
#
#      type	   - 'C' = conference, 'H' = subheading
#      name	   - Name to join conference by, text of heading
#      title	   - Longer name of conference
#      des	   - Description of conference or category
 
sub ft_conflist {
    my (@cla, $i, $page, $in, $type, $name, $title, $des);

    $page= ft_runscript($sysh, "/fronttalk/conflist", '', 1)
    	or return undef;

    print "CONFLIST:\n$page\n" if $debug;

    # Parse info
    $i= 0;
    while ($tok= ft_parse(\$page,$in))
    {
	if ($tok->{TOKEN} eq 'text' and $in)
	{
	    $h->{des}= $tok->{TEXT};
	}
	elsif ($tok->{TOKEN} eq 'CF' or $tok->{TOKEN} eq 'CAT')
	{
	    $in= $cla[$i]->{type}= (($tok->{TOKEN} eq 'CF') ? 'C' : 'H');
	    $h= $cla[$i];
	    $i++;

	    $h->{name}= ft_unquote($tok->{NAME});
	    $h->{title}= ft_unquote($tok->{TITLE});
	}
	elsif ($tok->{TOKEN} eq '/CF' or $tok->{TOKEN} eq '/CAT')
	{
	    $in= undef;
	}
    }

    return @cla;
}


# ft_check($conflist)
#  Get an array of handles for the hot list conferences, or the given
#  conferences if $conflist is not empty.  Each array element has the
#  following hash fields:
#
#      name	   - Name of conference
#      err	   - 'Not accessible', etc
#      total	   - number of items
#      newr 	   - number of new response items
#      newi 	   - number of brand new items
#      unseen 	   - number of unseen items
 
sub ft_check {
    my ($conflist)= @_;
    my (@cha, $i, $page, $h);

    $conflist= "csel=".ft_httpquote($conflist) if $conflist;

    $page= ft_runscript($sysh, "/fronttalk/check", $conflist, 1)
    	or return undef;

    print "CHECK:\n$page\n" if $debug;

    # Parse info
    $i= 0;
    while ($tok= ft_parse(\$page))
    {
	if ($tok->{TOKEN} eq 'CHECK')
	{
	    $cha[$i]->{name}= ft_unquote($tok->{NAME});
	    $h= $cha[$i];
	    $i++;

	    $h->{err}= $tok->{ERR};
	    $h->{total}= $tok->{TOTAL};
	    $h->{newr}= $tok->{NEWR};
	    $h->{newi}= $tok->{NEWI};
	    $h->{unseen}= $tok->{UNSEEN};
	}
    }

    return @cha;
}


1;
